@@ -12,6 +12,7 @@ conditional constraints.
 
 """
 import ast
+import builtins
 import copy
 import functools
 import inspect
@@ -53,7 +54,7 @@ import modeci_mdf.functions.actr as actr_funcs
 
 FORMAT_DEFAULT = FORMAT_NUMPY
 
-KNOWN_PARAMETERS = ["constant"]
+KNOWN_PARAMETERS = ["constant", "math", "numpy"] + dir(builtins)
 
 
 time_scale_str_regex = r"(TimeScale)?\.(.*)"
@@ -159,7 +160,7 @@ def evaluate_onnx_expr(
         for k, v in kwargs_for_onnx.items()
         if (
             (k in onnx_arguments or has_variadic)
-            and "onnx::" not in k  # filter Evaluable__ class names
+            and "onnx_" not in k  # filter Evaluable__ class names
         )
     }
 
@@ -778,8 +779,20 @@ class EvaluableNode:
 
                     # If we are dealing with a list of symbols, each must treated separately
                     all_req_vars.extend(
-                        get_required_variables_from_expression(arg_expr)
+                        [
+                            v
+                            for v in get_required_variables_from_expression(arg_expr)
+                            if v not in f.args
+                        ]
                     )
+            if f.value is not None:
+                all_req_vars.extend(
+                    [
+                        v
+                        for v in get_required_variables_from_expression(f.value)
+                        if f.args is None or v not in f.args
+                    ]
+                )
 
             all_present = [v in all_known_vars for v in all_req_vars]
             func_missing_vars[f.id] = {
@@ -839,14 +852,26 @@ class EvaluableNode:
             all_req_vars = []
 
             if p.value is not None and type(p.value) == str:
-                all_req_vars.extend(get_required_variables_from_expression(p.value))
+                all_req_vars.extend(
+                    [
+                        v
+                        for v in get_required_variables_from_expression(p.value)
+                        if p.args is None or v not in p.args
+                    ]
+                )
 
             if p.args is not None:
                 for arg in p.args:
                     arg_expr = p.args[arg]
                     if isinstance(arg_expr, str):
                         all_req_vars.extend(
-                            get_required_variables_from_expression(arg_expr)
+                            [
+                                v
+                                for v in get_required_variables_from_expression(
+                                    arg_expr
+                                )
+                                if v not in p.args
+                            ]
                         )
 
             all_known_vars_plus_this = all_known_vars + [p.id]
